@@ -217,52 +217,57 @@ def compute_streamlines(x, y, u, v, density=1.0):
 
 
 class BokehBackend(Plot):
-    """A backend for plotting SymPy's symbolic expressions using Bokeh.
-    Note: this implementation only implements 2D plots.
+    """
+    A backend for plotting SymPy's symbolic expressions using Bokeh.
+    This implementation only supports 2D plots.
 
-    Keyword Arguments
-    =================
+    Parameters
+    ==========
 
-        contour_kw : dict
-            A dictionary with keyword arguments to customize the contour.
-            This might be useful to change the `palette` to a custom value.
+    contour_kw : dict, optional
+        A dictionary with keyword arguments to customize the contour.
+        This might be useful to change the `palette` to a custom value.
 
-        line_kw : dict
-            A dictionary of keywords/values which is passed to Plotly's scatter
-            functions to customize the appearance. Default to:
-            ``line_kw = dict(line_width = 2)``
-            Refer to this documentation page:
-            https://docs.bokeh.org/en/latest/docs/reference/plotting.html?highlight=line#bokeh.plotting.Figure.line
+    line_kw : dict, optional
+        A dictionary of keywords/values which is passed to Plotly's scatter
+        functions to customize the appearance. Default to:
+        ``line_kw = dict(line_width = 2)``
+        Refer to this documentation page:
+        https://docs.bokeh.org/en/latest/docs/reference/plotting.html?highlight=line#bokeh.plotting.Figure.line
 
-        quiver_kw : dict
-            A dictionary with keyword arguments to customize the quivers.
-            Default to:
-                ```dict(
-                        scale = 1,
-                        pivot = "mid",      # can be "mid", "tip" or "tail"
-                        arrow_heads = True,  # show/hide arrow
-                        line_width = 1
-                    )
-                ```
+    quiver_kw : dict, optional
+        A dictionary with keyword arguments to customize the quivers.
+        Default to
 
-        stream_kw : dict
-            A dictionary with keyword arguments to customize the streamlines.
-            Default to: ``dict(line_width=2, line_alpha=0.8)``
+        .. code-block:: python
 
-        theme : str
-            Set the theme. Default to "dark_minimal". Find more Bokeh themes at
-            the following page:
-            https://docs.bokeh.org/en/latest/docs/reference/themes.html
+           dict(
+               scale = 1,
+               pivot = "mid",      # "mid", "tip" or "tail"
+               arrow_heads = True,  # show/hide arrow
+               line_width = 1
+           )
 
-    Export
-    ======
+    stream_kw : dict, optional
+        A dictionary with keyword arguments to customize the streamlines.
+        Default to: ``dict(line_width=2, line_alpha=0.8)``
 
-    In order to export the plots you will need to install the packages listed
-    in the following page:
+    theme : str, optional
+        Set the theme. Default to ``"dark_minimal"``. Find more Bokeh themes
+        at the following page:
+        https://docs.bokeh.org/en/latest/docs/reference/themes.html
+
+
+    Notes
+    =====
+
+    In order to export the plots, the user also need to install the packages
+    listed in the following page:
     https://docs.bokeh.org/en/latest/docs/user_guide/export.html
 
     At the time of writing this backend, geckodriver is not available to pip.
     Do a quick search on the web to find the appropriate installer.
+
     """
 
     _library = "bokeh"
@@ -499,15 +504,15 @@ class BokehBackend(Plot):
                         self._fig.add_layout(colorbar, "right")
                         self._handles[i] = colorbar
 
-            elif s.is_complex and s.is_domain_coloring:
-                x, y, magn_angle, img, colors = s.get_data()
+            elif s.is_complex and s.is_domain_coloring and not s.is_3Dsurface:
+                x, y, mag, angle, img, colors = s.get_data()
                 img = self._get_img(img)
 
                 source = ColumnDataSource(
                     {
                         "image": [img],
-                        "abs": [magn_angle[:, :, 0]],
-                        "arg": [magn_angle[:, :, 1]],
+                        "abs": [mag],
+                        "arg": [angle],
                     }
                 )
 
@@ -534,17 +539,6 @@ class BokehBackend(Plot):
                     )
                     self._fig.add_layout(colorbar1, "right")
 
-                if s.coloring == "f":
-                    # lightness/magnitude-colorbar
-                    cm2 = LinearColorMapper(palette=bp.gray(100), low=0, high=1)
-                    colorbar2 = ColorBar(
-                        color_mapper=cm2,
-                        title="Magnitude",
-                        ticker=FixedTicker(ticks=[0, 1]),
-                        major_label_overrides={0: "0", 1: "∞"},
-                    )
-                    self._fig.add_layout(colorbar2, "right")
-
             elif s.is_geometry:
                 x, y = s.get_data()
                 color = next(self._cl)
@@ -702,15 +696,15 @@ class BokehBackend(Plot):
                         rend[i].data_source.data.update(data)
                         rend[i].glyph.line_color = line_color
 
-                elif s.is_complex and s.is_domain_coloring:
+                elif s.is_complex and s.is_domain_coloring and not s.is_3Dsurface:
                     # TODO: for some unkown reason, domain_coloring and
                     # interactive plot don't like each other...
-                    x, y, magn_angle, img, _ = s.get_data()
+                    x, y, mag, angle, img, _ = s.get_data()
                     img = self._get_img(img)
                     source = {
                         "image": [img],
-                        "abs": [magn_angle[:, :, 0]],
-                        "arg": [magn_angle[:, :, 1]],
+                        "abs": [mag],
+                        "arg": [angle],
                     }
                     rend[i].data_source.data.update(source)
 
@@ -720,9 +714,20 @@ class BokehBackend(Plot):
                     rend[i].data_source.data.update(source)
 
     def save(self, path, **kwargs):
-        self._process_series(self._series)
+        # TODO: an error get raised if I uncomment the following line
+        # self._process_series(self._series)
         ext = os.path.splitext(path)[1]
-        if ext == ".svg":
+
+        # TODO:
+        # https://docs.bokeh.org/en/latest/docs/user_guide/embed.html
+        
+        if (ext == ".html") or (ext == ".htm"):
+            from bokeh.resources import CDN
+            from bokeh.embed import file_html
+            html = file_html(self.fig, CDN, "bokeh_plot")
+            with open(path, 'w') as f:
+                f.write(html)
+        elif ext == ".svg":
             self._fig.output_backend = "svg"
             export_svg(self.fig, filename=path)
         else:
