@@ -17,34 +17,35 @@ import colorcet as cc
 class K3DBackend(Plot):
     """A backend for plotting SymPy's symbolic expressions using K3D-Jupyter.
 
-    Keyword Arguments
-    =================
+    Parameters
+    ==========
 
-        line_kw : dict
-            A dictionary of keywords/values which is passed to K3D's line
-            functions to customize the appearance. Default to:
-            ``line_kw = dict(width=0.1, shader="mesh")``
-            Set `use_cm=False` to switch to a solid color.
+    line_kw : dict, optional
+        A dictionary of keywords/values which is passed to K3D's line
+        functions to customize the appearance. Default to:
+        ``line_kw = dict(width=0.1, shader="mesh")``
+        Set ``use_cm=False`` to switch to a solid color.
 
-        quiver_kw : dict
-            A dictionary to customize the apppearance of quivers. Default to:
-            ``quiver_kw = dict(scale = 1)``.
-            Set `use_cm=False` to switch to a solid color.
+    quiver_kw : dict, optional
+        A dictionary to customize the apppearance of quivers. Default to:
+        ``quiver_kw = dict(scale = 1)``.
+        Set ``use_cm=False`` to switch to a solid color.
 
-        show_label : boolean
-            Show/hide labels of the expressions. Default to False (labels not
-            visible).
+    show_label : boolean, optional
+        Show/hide labels of the expressions. Default to False (labels not
+        visible).
 
-        stream_kw : dict
-            A dictionary to customize the apppearance of streamlines.
-            Default to:
-            ``stream_kw = dict( width=0.1, shader='mesh' )``
-            Refer to k3d.line for more options.
-            Set `use_cm=False` to switch to a solid color.
+    stream_kw : dict, optional
+        A dictionary to customize the apppearance of streamlines.
+        Default to:
+        ``stream_kw = dict( width=0.1, shader='mesh' )``
+        Refer to k3d.line for more options.
+        Set ``use_cm=False`` to switch to a solid color.
+
+    use_cm : boolean, optional
+        If True, apply a color map to the meshes/surface. If False, solid
+        colors will be used instead. Default to True.
 
-        use_cm : boolean
-            If True, apply a color map to the meshes/surface. If False, solid
-            colors will be used instead. Default to True.
     """
 
     _library = "k3d"
@@ -381,8 +382,7 @@ class K3DBackend(Plot):
                 self._fig += vec
 
             elif s.is_complex and s.is_3Dsurface:
-                x, y, mag_arg, colors, colorscale = s.get_data()
-                mag, arg = mag_arg[:, :, 0], mag_arg[:, :, 1]
+                x, y, mag, arg, colors, colorscale = s.get_data()
 
                 x, y, z = [t.flatten() for t in [x, y, mag]]
                 vertices = np.vstack([x, y, z]).T.astype(np.float32)
@@ -499,19 +499,16 @@ class K3DBackend(Plot):
                     vectors = np.array((uu, vv, ww)).T * scale
                     self.fig.objects[i].vectors = vectors
 
-                elif s.is_complex:
-                    if s.is_3Dsurface:
-                        x, y, mag_arg, colors, colorscale = s.get_data()
-                        mag, arg = mag_arg[:, :, 0], mag_arg[:, :, 1]
-                        x, y, z = [t.flatten().astype(np.float32) for t in [x, y, mag]]
-                        vertices = np.vstack([x, y, z]).astype(np.float32)
-                        self._fig.objects[i].vertices = vertices.T
-                        if self._use_cm:
-                            colors = colors.reshape((-1, 3))
-                            colors = [self._rgb_to_int(c) for c in colors]
-                            self._fig.objects[i].colors = colors
-                    else:
-                        raise NotImplementedError
+                elif s.is_complex and s.is_3Dsurface:
+                    x, y, mag, _, colors, _ = s.get_data()
+                    x, y, z = [t.flatten().astype(np.float32) for t in [x, y, mag]]
+                    vertices = np.vstack([x, y, z]).astype(np.float32)
+                    self._fig.objects[i].vertices = vertices.T
+                    if self._use_cm:
+                        colors = colors.reshape((-1, 3))
+                        colors = [self._rgb_to_int(c) for c in colors]
+                        self._fig.objects[i].colors = colors
+
         # self._fig.auto_rendering = True
 
     def show(self):
