@@ -54,83 +54,81 @@ def _matplotlib_list(interval_list):
 
 
 class MatplotlibBackend(Plot):
-    """A backend for plotting SymPy's symbolic expressions using Matplotlib.
+    """
+    A backend for plotting SymPy's symbolic expressions using Matplotlib.
 
-    Keyword Arguments
-    =================
+    Parameters
+    ==========
 
-        aspect : str or tuple
-            Default to "auto". Possible values:
-                * "equal": sets equal spacing on the axis of a 2D plot.
-                * tuple containing 2 float numbers
+    aspect : str or tuple, optional
+        Default to ``"auto"``. Possible values:
 
-        axis_center : str or None
-            Set the location of the intersection between the horizontal and
-            vertical axis (only works for 2D plots). Possible values:
-                "center": center of the current plot area.
-                "auto": an algorithm will choose an appropriate value.
-                tuple of two float numbers to specify the interested center.
-                None: standard Matplotlib layout with vertical axis on the left,
-                    horizontal axis on the bottom and a grid.
-            Default to "auto".
+        * ``"equal"``: sets equal spacing on the axis of a 2D plot.
+        * tuple containing 2 float numbers
 
-        contour_kw : dict
-            A dictionary of keywords/values which is passed to Matplotlib's
-            contour/contourf function to customize the appearance.
-            Refer to the following web page to learn more about customization:
-            https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.contourf.html
+    axis_center : str or None, optional
+        Set the location of the intersection between the horizontal and
+        vertical axis (only works for 2D plots). Possible values:
 
-        image_kw : dict
-            A dictionary of keywords/values which is passed to Matplotlib's
-            imshow function to customize the appearance.
-            Refer to the following web page to learn more about customization:
-            https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.imshow.html
+        * ``"center"``: center of the current plot area.
+        * ``"auto"``: an algorithm will choose an appropriate value.
+        * tuple of two float numbers to specify the interested center.
+        * ``None``: standard Matplotlib layout with vertical axis on the left,
+          horizontal axis on the bottom and a grid.
+        
+        Default to ``"auto"``.
 
-        line_kw : dict
-            A dictionary of keywords/values which is passed to Matplotlib's
-            plot functions to customize the appearance of the lines.
-            Refer to the following web pages to learn more about customization:
-                If the plot is using solid colors:
-                https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.plot.html
-                If the plot is using color maps:
-                https://matplotlib.org/stable/api/collections_api.html#matplotlib.collections.LineCollection
+    contour_kw : dict, optional
+        A dictionary of keywords/values which is passed to Matplotlib's
+        contour/contourf function to customize the appearance.
+        Refer to the following web page to learn more about customization:
+        https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.contourf.html
 
-        quiver_kw : dict
-            A dictionary of keywords/values which is passed to Matplotlib's
-            quivers function to customize the appearance.
-            Refer to this documentation page:
-            https://matplotlib.org/stable/api/quiver_api.html#module-matplotlib.quiver
+    image_kw : dict, optional
+        A dictionary of keywords/values which is passed to Matplotlib's
+        imshow function to customize the appearance.
+        Refer to the following web page to learn more about customization:
+        https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.imshow.html
 
-        surface_kw : dict
-            A dictionary of keywords/values which is passed to Matplotlib's
-            surface function to customize the appearance.
-            Refer to this documentation page:
-            https://matplotlib.org/stable/api/_as_gen/mpl_toolkits.mplot3d.axes3d.Axes3D.html#mpl_toolkits.mplot3d.axes3d.Axes3D.plot_surface
+    line_kw : dict, optional
+        A dictionary of keywords/values which is passed to Matplotlib's plot
+        functions to customize the appearance of the lines.
+        Refer to the following web pages to learn more about customization:
+        
+        * If the plot is using solid colors:
+          https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.plot.html
+        * If the plot is using color maps:
+          https://matplotlib.org/stable/api/collections_api.html#matplotlib.collections.LineCollection
 
-        stream_kw : dict
-            A dictionary of keywords/values which is passed to Matplotlib's
-            streamplot function to customize the appearance.
-            For 2D vector fields, refer to this documentation page:
-            https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.streamplot.html#matplotlib.axes.Axes.streamplot
+    quiver_kw : dict, optional
+        A dictionary of keywords/values which is passed to Matplotlib's quivers
+        function to customize the appearance.
+        Refer to this documentation page:
+        https://matplotlib.org/stable/api/quiver_api.html#module-matplotlib.quiver
+
+    surface_kw : dict, optional
+        A dictionary of keywords/values which is passed to Matplotlib's
+        surface function to customize the appearance.
+        Refer to this documentation page:
+        https://matplotlib.org/stable/api/_as_gen/mpl_toolkits.mplot3d.axes3d.Axes3D.html#mpl_toolkits.mplot3d.axes3d.Axes3D.plot_surface
+
+    stream_kw : dict, optional
+        A dictionary of keywords/values which is passed to Matplotlib's
+        streamplot function to customize the appearance.
+        For 2D vector fields, refer to this documentation page:
+        https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.streamplot.html#matplotlib.axes.Axes.streamplot
+
+    use_cm : boolean, optional
+        If True, apply a color map to the mesh/surface or parametric lines.
+        If False, solid colors will be used instead. Default to True.
 
-        use_cm : boolean
-            If True, apply a color map to the mesh/surface or parametric lines.
-            If False, solid colors will be used instead. Default to True.
     """
 
     _library = "matplotlib"
 
     colormaps = [
-        cm.viridis,
-        cm.autumn,
-        cm.winter,
-        cm.plasma,
-        cm.jet,
-        cm.gnuplot,
-        cm.brg,
-        cm.coolwarm,
-        cm.cool,
-        cm.summer,
+        cm.viridis, cm.autumn, cm.winter, cm.plasma, cm.jet,
+        cm.gnuplot, cm.brg, cm.coolwarm, cm.cool, cm.summer,
     ]
 
     cyclic_colormaps = [cm.twilight, cm.hsv]
@@ -190,7 +188,7 @@ class MatplotlibBackend(Plot):
         aspect = self.aspect
         if aspect != "auto":
             if aspect == "equal" and is_3Dvector:
-                # vector_plot uses an aspect="equal" by default. In that case
+                # plot_vector uses an aspect="equal" by default. In that case
                 # we would get:
                 # NotImplementedError: Axes3D currently only supports the aspect
                 # argument 'auto'. You passed in 1.0.
@@ -227,7 +225,8 @@ class MatplotlibBackend(Plot):
 
     @staticmethod
     def get_segments(x, y, z=None):
-        """Convert two list of coordinates to a list of segments to be used
+        """
+        Convert two list of coordinates to a list of segments to be used
         with Matplotlib's LineCollection.
 
         Parameters
@@ -507,12 +506,12 @@ class MatplotlibBackend(Plot):
                         self._add_handle(i, q, kw, is_cb_added, self._fig.axes[-1])
                     xlims.append((np.amin(xx), np.amax(xx)))
                     ylims.append((np.amin(yy), np.amax(yy)))
-                    zlims.append((np.amin(zz), np.amax(zz)))
+                    zlims.append((np.nanmin(zz), np.nanmax(zz)))
 
             elif s.is_complex:
                 if not s.is_3Dsurface:
                     # x, y, magn_angle, img, discr, colors = self._get_image(s)
-                    x, y, _, img, colors = s.get_data()
+                    x, y, _, _, img, colors = s.get_data()
                     image_kw = self._kwargs.get("image_kw", dict())
                     ikw = dict(
                         extent=[np.amin(x), np.amax(x), np.amin(y), np.amax(y)],
@@ -523,17 +522,6 @@ class MatplotlibBackend(Plot):
                     image = self.ax.imshow(img, **kw)
                     self._add_handle(i, image, kw)
 
-                    # lightness/magnitude-colorbar
-                    if s.coloring == "f":
-                        cb1 = self._fig.colorbar(
-                            cm.ScalarMappable(cmap=cm.Greys_r),
-                            orientation="vertical",
-                            label="Magnitude",
-                            ticks=[0, 1],
-                            ax=self.ax,
-                        )
-                        cb1.ax.set_yticklabels(["0", r"$\infty$"])
-
                     # chroma/phase-colorbar
                     if colors is not None:
                         colors = colors / 255.0
@@ -551,8 +539,7 @@ class MatplotlibBackend(Plot):
                             [r"-$\pi$", r"-$\pi / 2$", "0", r"$\pi / 2$", r"$\pi$"]
                         )
                 else:
-                    x, y, mag_arg, facecolors, colorscale = s.get_data()
-                    mag = mag_arg[:, :, 0]
+                    x, y, mag, arg, facecolors, colorscale = s.get_data()
 
                     skw = dict(rstride=1, cstride=1, linewidth=0.1)
                     if self._use_cm:
@@ -846,7 +833,7 @@ class MatplotlibBackend(Plot):
                         self._update_colorbar(cax, magn, kw, s.label)
                     xlims.append((np.amin(xx), np.amax(xx)))
                     ylims.append((np.amin(yy), np.amax(yy)))
-                    zlims.append((np.amin(zz), np.amax(zz)))
+                    zlims.append((np.nanmin(zz), np.nanmax(zz)))
 
                 elif s.is_vector:
                     xx, yy, uu, vv = self.series[i].get_data()
@@ -875,12 +862,11 @@ class MatplotlibBackend(Plot):
 
                 elif s.is_complex:
                     if not s.is_3Dsurface:
-                        x, y, _, img, colors = s.get_data()
+                        x, y, _, _, img, colors = s.get_data()
                         self._handles[i][0].remove()
                         self._handles[i][0] = self.ax.imshow(img, **self._handles[i][1])
                     else:
-                        x, y, mag_arg, facecolors, colorscale = s.get_data()
-                        mag = mag_arg[:, :, 0]
+                        x, y, mag, arg, facecolors, colorscale = s.get_data()
                         self._handles[i][0].remove()
                         kw = self._handles[i][1]
 
