@@ -246,7 +246,7 @@ class LineOver1DRangeSeries(Line2DBaseSeries):
         self.polar = kwargs.get("polar", False)
         self.modules = kwargs.get("modules", None)
         self.absarg = kwargs.get("absarg", None)
-        if self.absarg is not None:
+        if self.is_complex and (self.absarg is not None):
             self.is_parametric = True
 
     def __str__(self):
@@ -732,8 +732,8 @@ class SurfaceOver2DRangeSeries(SurfaceBaseSeries):
         self.start_y = func(var_start_end_y[1])
         self.end_y = func(var_start_end_y[2])
         self.label = label
-        self.n1 = kwargs.get("n1", 50)
-        self.n2 = kwargs.get("n2", 50)
+        self.n1 = kwargs.get("n1", 100)
+        self.n2 = kwargs.get("n2", 100)
         self.xscale = kwargs.get("xscale", "linear")
         self.yscale = kwargs.get("yscale", "linear")
         self.modules = kwargs.get("modules", None)
@@ -1208,6 +1208,7 @@ class InteractiveSeries(BaseSeries):
         self.modules = kwargs.get("modules", None)
         self.absarg = kwargs.get("absarg", None)
 
+        self.polar = kwargs.get("polar", False)
         self.xscale = kwargs.get("xscale", "linear")
         self.yscale = kwargs.get("yscale", "linear")
         self.label = label
@@ -1431,6 +1432,11 @@ class InteractiveSeries(BaseSeries):
                 results = [np.real(r) for r in results]
             else:
                 results = [*self.ranges.values(), results]
+                if self.is_2Dline and self.polar:
+                    # TODO: test this!!!!
+                    t = results[0].copy()
+                    k = results[1].copy()
+                    results = [k * np.cos(t), k * np.sin(t)]
             self.data = results
 
         elif self.is_implicit:
@@ -1512,6 +1518,12 @@ class ComplexPointSeries(BaseSeries):
     def get_data(self):
         return self._evaluate(self.expr)
 
+    def __str__(self):
+        p = "point"
+        if len(self.expr) > 1:
+            p += "s"
+        return "complex %s %s" % (p, self.expr)
+
 class ComplexPointInteractiveSeries(InteractiveSeries, ComplexPointSeries):
     def __init__(self, expr, label="", **kwargs):
         self._init_attributes(expr, label)
@@ -1561,7 +1573,6 @@ class ComplexSeries(BaseSeries):
         if kwargs.get("threed", False):
             self.is_3Dsurface = True
 
-        # TODO: do I need this???
         from sympy import lambdify
         self.function = lambdify([self.var], expr, modules=self.modules)
 
@@ -1574,13 +1585,23 @@ class ComplexSeries(BaseSeries):
 
         # domain coloring mode
         self.coloring = kwargs.get("coloring", "a")
-        if not isinstance(self.coloring, str):
-            raise ValueError("`coloring` must be of type string.")
-        self.coloring = self.coloring.lower()
+        if isinstance(self.coloring, str):
+            self.coloring = self.coloring.lower()
+        elif not callable(self.coloring):
+            raise TypeError(
+                "`coloring` must be a character from 'a' to 'j' or a callable.")
         self.phaseres = kwargs.get("phaseres", 20)
-        # these will be passed to cplot.get_srgb1
-        self.abs_scaling = kwargs.get("abs_scaling", "h-1")
-        self.colorspace = kwargs.get("colorspace", "cam16")
+
+    def __str__(self):
+        from sympy import re, im
+        prefix = "cartesian surface" if self.is_3Dsurface else "domain coloring"
+        return (prefix + ": %s for" " %s over %s and %s over %s") % (
+                str(self.expr),
+                str(re(self.var)),
+                str((self.start.real, self.end.real)),
+                str(im(self.var)),
+                str((self.start.imag, self.end.imag)),
+            )
 
     def _correct_output(self, x, r):
         """Obtain the correct output depending the initialized settings.
@@ -1603,68 +1624,17 @@ class ComplexSeries(BaseSeries):
 
         # 2D or 3D domain coloring
         return (
-            np.real(x),
-            np.imag(x),
-            np.dstack([np.absolute(r), np.angle(r)]),
+            np.real(x), np.imag(x),
+            np.absolute(r), np.angle(r),
             *self._domain_coloring(r),
         )
 
     def _domain_coloring(self, w):
-        from spb.ccomplex.hsv_color_grading import color_grading
-        from spb.ccomplex.wegert import (
-            bw_stripes_phase,
-            bw_stripes_mag,
-            domain_coloring,
-            enhanced_domain_coloring,
-            enhanced_domain_coloring_phase,
-            enhanced_domain_coloring_mag,
-            bw_stripes_imag,
-            bw_stripes_real,
-            cartesian_chessboard,
-            polar_chessboard,
-        )
-        from cplot import get_srgb1
-
-        _mapping = {
-            "a": domain_coloring,
-            "b": enhanced_domain_coloring,
-            "c": enhanced_domain_coloring_mag,
-            "d": enhanced_domain_coloring_phase,
-            "e": color_grading,
-            "f": None,
-            "g": bw_stripes_mag,
-            "h": bw_stripes_phase,
-            "i": bw_stripes_real,
-            "j": bw_stripes_imag,
-            "k": cartesian_chessboard,
-            "l": polar_chessboard,
-        }
-        colorscale = None
-        if self.coloring not in _mapping.keys():
-            raise KeyError(
-                "`coloring` must be one of the following: {}".format(_mapping.keys())
-            )
-
-        if self.coloring == "f":
-            zn = 1 * np.exp(1j * np.linspace(0, 2 * np.pi, 256))
-            colorscale = get_srgb1(zn, self.abs_scaling, self.colorspace)
-            colorscale = (colorscale * 255).astype(np.uint8)
-            # shift the argument from [0, 2*pi] to [-pi, pi]
-            colorscale = np.roll(colorscale, int(len(colorscale) / 2), axis=0)
-            rgb = (get_srgb1(w, self.abs_scaling, self.colorspace) * 255).astype(
-                np.uint8
-            )
-            return rgb, colorscale
-
-        if self.coloring <= "e":
-            from matplotlib.colors import hsv_to_rgb
-
-            H = np.linspace(0, 1, 256)
-            S = V = np.ones_like(H)
-            colorscale = hsv_to_rgb(np.dstack([H, S, V]))
-            colorscale = (colorscale.reshape((-1, 3)) * 255).astype(np.uint8)
-            colorscale = np.roll(colorscale, int(len(colorscale) / 2), axis=0)
-        return _mapping[self.coloring](w, phaseres=self.phaseres), colorscale
+        if isinstance(self.coloring, str):
+            from spb.ccomplex.wegert import wegert
+            self.coloring = self.coloring.lower()
+            return wegert(self.coloring, w, self.phaseres)
+        return self.coloring(w)
 
     def get_data(self):
         if isinstance(self.expr, (list, tuple, Tuple)):
@@ -1794,6 +1764,13 @@ class Vector2DSeries(VectorBase):
         self.v = SurfaceOver2DRangeSeries(v, range1, range2, **kwargs)
         self.label = label
 
+    def __str__(self):
+        r1 = (self.u.var_x, self.u.start_x, self.u.end_x)
+        r2 = (self.u.var_y, self.u.start_y, self.u.end_y)
+        return "2D vector series: [%s, %s] over %s, %s" % (
+            self.u.expr, self.v.expr, r1, r2
+        )
+
     def get_data(self):
         x, y, u = self.u.get_data()
         _, _, v = self.v.get_data()
@@ -1827,6 +1804,14 @@ class Vector3DSeries(VectorBase):
         self.yscale = kwargs.get("yscale", "linear")
         self.zscale = kwargs.get("zscale", "linear")
 
+    def __str__(self):
+        r1 = (self.var_x, self.start_x, self.end_x)
+        r2 = (self.var_y, self.start_y, self.end_y)
+        r3 = (self.var_z, self.start_z, self.end_z)
+        return "3D vector series: [%s, %s, %s] over %s, %s, %s" % (
+            self.u, self.v, self.w, r1, r2, r3
+        )
+
     def _discretize(self):
         """This method allows to reduce code repetition."""
         x = super()._discretize(self.start_x, self.end_x, self.n1, self.xscale)
@@ -1876,6 +1861,16 @@ class SliceVector3DSeries(Vector3DSeries):
         """This method allows to reduce code repetition."""
         return self.plane.get_data()
 
+    def __str__(self):
+        s = "sliced " + super().__str__() + " with plane {}".format(self.plane.plane)
+        return s
+        # r1 = (self.var_x, self.start_x, self.end_x)
+        # r2 = (self.var_y, self.start_y, self.end_y)
+        # r3 = (self.var_z, self.start_z, self.end_z)
+        # return "3D vector series: [%s, %s, %s] over %s, %s, %s" % (
+        #     self.u, self.v, self.w, r1, r2, r3
+        # )
+
 
 class PlaneSeries(SurfaceBaseSeries):
     """Represents a plane in a 3D domain."""
@@ -1900,6 +1895,11 @@ class PlaneSeries(SurfaceBaseSeries):
         self.zscale = kwargs.get("zscale", "linear")
         self.params = params
 
+    def __str__(self):
+        return "plane series of %s over %s, %s, %s" % (
+            self.plane, self.x_range, self.y_range, self.z_range
+        )
+
     def get_data(self):
         x, y, z = symbols("x, y, z")
         plane = self.plane.subs(self.params)
@@ -2087,6 +2087,9 @@ class GeometrySeries(BaseSeries):
                 y = m * x + q
             return x.astype(float), y.astype(float)
 
+    def __str__(self):
+        return "geometry entity: %s" % str(self.expr)
+
 
 class GeometryInteractiveSeries(GeometrySeries, InteractiveSeries):
     """Represent a geometry entity.
